@@ -1,5 +1,6 @@
 #!/usr/bin/env python3
 """Script to convert package setup to myst-docutils."""
+
 import sys
 
 import tomlkit
@@ -16,7 +17,7 @@ def modify_toml(content: str) -> str:
     dependencies = []
     sphinx_extra = []
     for dep in doc["project"]["dependencies"]:
-        if dep.startswith("docutils") or dep.startswith("sphinx"):
+        if dep.startswith(("docutils", "sphinx")):
             sphinx_extra.append(dep)
         else:
             dependencies.append(dep)
