@@ -4,9 +4,7 @@
 # list see the documentation:
 # https://www.sphinx-doc.org/en/master/usage/configuration.html
 
-import hashlib
 from datetime import date
-from pathlib import Path
 
 from sphinx.application import Sphinx
 
@@ -56,7 +54,7 @@ exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]
 suppress_warnings = ["myst.strikethrough"]
 
 intersphinx_mapping = {
-    "python": ("https://docs.python.org/3.7", None),
+    "python": ("https://docs.python.org/3.10", None),
     "sphinx": ("https://www.sphinx-doc.org/en/master", None),
     "markdown_it": ("https://markdown-it-py.readthedocs.io/en/latest", None),
 }
@@ -85,6 +83,7 @@ nitpicky = True
 nitpick_ignore_regex = [
     (r"py:.*", r"docutils\..*"),
     (r"py:.*", r"pygments\..*"),
+    (r"py:.*", r"typing\.Literal\[.*"),
 ]
 nitpick_ignore = [
     ("py:obj", "myst_parser._docs._ConfigBase"),
@@ -154,20 +153,20 @@ html_favicon = "_static/logo-square.svg"
 html_title = ""
 html_theme_options = {
     "home_page_in_toc": True,
-    "github_url": "https://github.com/executablebooks/MyST-Parser",
+    # "github_url": "https://github.com/executablebooks/MyST-Parser",
     "repository_url": "https://github.com/executablebooks/MyST-Parser",
     "repository_branch": "master",
     "path_to_docs": "docs",
     "use_repository_button": True,
     "use_edit_page_button": True,
     "use_issues_button": True,
-    "announcement": "<b>v2.0.0</b> is now out! See the Changelog for details",
+    # "announcement": "<b>v3.0.0</b> is now out! See the Changelog for details",
 }
 html_last_updated_fmt = ""
 # OpenGraph metadata
 ogp_site_url = "https://myst-parser.readthedocs.io/en/latest"
 # This is the image that GitHub stores for our social media previews
-ogp_image = "https://repository-images.githubusercontent.com/240151150/316bc480-cc23-11eb-96fc-4ab2f981a65d"  # noqa: E501
+ogp_image = "https://repository-images.githubusercontent.com/240151150/316bc480-cc23-11eb-96fc-4ab2f981a65d"
 ogp_custom_meta_tags = [
     '<meta name="twitter:card" content="summary_large_image">',
 ]
@@ -233,16 +232,4 @@ def setup(app: Sphinx):
     app.add_directive("myst-to-html", MystToHTMLDirective)
     app.add_post_transform(StripUnsupportedLatex)
     app.add_post_transform(NumberSections)
-    app.connect("html-page-context", add_version_to_css)
     app.add_lexer("myst", MystLexer)
-
-
-def add_version_to_css(app: Sphinx, pagename, templatename, context, doctree):
-    """Add the version number to the local.css file, to bust the cache for changes."""
-    if app.builder.name != "html":
-        return
-    if "_static/local.css" in context.get("css_files", {}):
-        css = Path(app.srcdir, "_static/local.css").read_text("utf8")
-        hashed = hashlib.sha256(css.encode("utf-8")).hexdigest()
-        index = context["css_files"].index("_static/local.css")
-        context["css_files"][index] = f"_static/local.css?hash={hashed}"
