@@ -1,10 +1,8 @@
+import contextlib
 import io
 from dataclasses import dataclass, field, fields
 from textwrap import dedent
-
-import pytest
-from docutils import VersionInfo, __version_info__
-from typing_extensions import Literal
+from typing import Literal
 
 from myst_parser.mdit_to_docutils.base import make_document
 from myst_parser.parsers.docutils_ import (
@@ -12,9 +10,11 @@ from myst_parser.parsers.docutils_ import (
     attr_to_optparse_option,
     cli_html,
     cli_html5,
+    cli_html5_demo,
     cli_latex,
     cli_pseudoxml,
     cli_xml,
+    to_html5_demo,
 )
 
 
@@ -54,6 +54,18 @@ def test_cli_html5(monkeypatch, capsys):
     assert "text" in captured.out
 
 
+def test_cli_html5_demo(monkeypatch, capsys):
+    monkeypatch.setattr("sys.stdin", io.TextIOWrapper(io.BytesIO(b"text")))
+    cli_html5_demo([])
+    captured = capsys.readouterr()
+    assert not captured.err
+    assert "text" in captured.out
+
+
+def test_to_html5_demo():
+    assert to_html5_demo("text").strip() == "<p>text</p>"
+
+
 def test_cli_latex(monkeypatch, capsys):
     monkeypatch.setattr("sys.stdin", io.TextIOWrapper(io.BytesIO(b"text")))
     cli_latex([])
@@ -80,17 +92,19 @@ def test_cli_pseudoxml(monkeypatch, capsys):
 
 def test_help_text():
     """Test retrieving settings help text."""
-    from docutils.frontend import OptionParser
+    from docutils.core import Publisher
 
     stream = io.StringIO()
-    OptionParser(components=(Parser,)).print_help(stream)
+    pub = Publisher(parser=Parser())
+    with contextlib.redirect_stdout(stream):
+        try:
+            pub.process_command_line(["--help"])
+        except SystemExit as exc:
+            assert not exc.code
+
     assert "MyST options" in stream.getvalue()
 
 
-@pytest.mark.skipif(
-    __version_info__ < VersionInfo(0, 17, 0, "final", 0, True),
-    reason="parser option added in docutils 0.17",
-)
 def test_include_from_rst(tmp_path):
     """Test including a MyST file from within an RST file."""
     from docutils.parsers.rst import Parser as RSTParser
