@@ -1,10 +1,10 @@
 """Test (docutils) parsing with different ``MdParserConfig`` options set."""
+
 import shlex
 from io import StringIO
 from pathlib import Path
 
 import pytest
-from docutils import __version_info__
 from docutils.core import Publisher, publish_string
 from pytest_param_files import ParamTestData
 
@@ -17,20 +17,14 @@ INV_PATH = Path(__file__).parent.parent.absolute() / "static" / "objects_v2.inv"
 @pytest.mark.param_file(FIXTURE_PATH / "myst-config.txt")
 def test_cmdline(file_params: ParamTestData):
     """The description is parsed as a docutils commandline"""
-    if "url_schemes_list" in file_params.title and __version_info__ < (0, 18):
-        pytest.skip("problematic node ids changed in docutils 0.18")
-    if "heading_slug_func" in file_params.title and __version_info__ < (0, 18):
-        pytest.skip("dupnames ids changed in docutils 0.18")
     pub = Publisher(parser=Parser())
-    option_parser = pub.setup_option_parser()
     try:
-        settings = option_parser.parse_args(
-            shlex.split(file_params.description)
-        ).__dict__
+        pub.process_command_line(shlex.split(file_params.description or ""))
     except Exception as err:
         raise AssertionError(
             f"Failed to parse commandline: {file_params.description}\n{err}"
-        )
+        ) from err
+    settings = vars(pub.settings)
     report_stream = StringIO()
     settings["output_encoding"] = "unicode"
     settings["warning_stream"] = report_stream
