@@ -31,13 +31,14 @@ parameters available to parse to ``@pytest.mark.sphinx``:
 - docutilsconf=None
 
 """
+
 import os
 import pathlib
 import shutil
 
 import pytest
 from bs4 import BeautifulSoup
-from sphinx.testing.path import path
+from docutils import nodes
 
 from myst_parser._compat import findall
 
@@ -65,15 +66,11 @@ def get_sphinx_app_output(file_regression):
         regress_ext=".html",
         replace=None,
     ):
-        outpath = path(os.path.join(str(app.srcdir), "_build", buildername, filename))
+        outpath = pathlib.Path(str(app.srcdir), "_build", buildername, filename)
         if not outpath.exists():
             raise OSError(f"no output file exists: {outpath}")
 
-        try:
-            # introduced in sphinx 3.0
-            content = outpath.read_text(encoding=encoding)
-        except AttributeError:
-            content = outpath.text(encoding=encoding)
+        content = outpath.read_text(encoding=encoding)
 
         if regress_html:
             # only regress the inner body, since other sections are non-deterministic
@@ -82,7 +79,13 @@ def get_sphinx_app_output(file_regression):
             # pygments 2.11.0 introduces a whitespace tag
             for pygment_whitespace in doc_div.select("pre > span.w"):
                 pygment_whitespace.replace_with(pygment_whitespace.text)
+            # something changed in sphinx 8 (or new docutils) to introduce this, although I couldn't find the actual commit,
+            # but in any case, it's not important for the regression test
+            for clearer_div in doc_div.findAll("div", {"class": "clearer"}):
+                clearer_div.decompose()
             text = doc_div.prettify()
+            # changed in sphinx 7.2
+            text = text.replace('"Link to this', '"Permalink to this')
             for find, rep in (replace or {}).items():
                 text = text.replace(find, rep)
             file_regression.check(text, extension=regress_ext, encoding="utf8")
@@ -116,6 +119,13 @@ def get_sphinx_app_doctree(file_regression):
         ):
             node["source"] = pathlib.Path(node["source"]).name
 
+        doctree = doctree.deepcopy()
+
+        # remove attrs added in sphinx 7.1
+        doctree.attributes.pop("translation_progress", None)
+        for node in findall(doctree)(nodes.Element):
+            node.attributes.pop("translated", None)
+
         if regress:
             text = doctree.pformat()  # type: str
             for find, rep in (replace or {}).items():
